pub struct SendRawMessageLikeEvent<'a> { /* private fields */ }Expand description
Future returned by Room::send_raw.
Implementations
Sourceimpl<'a> SendRawMessageLikeEvent<'a>
impl<'a> SendRawMessageLikeEvent<'a>
Sourcepub fn with_sticky_duration(self, duration: Duration) -> Self
Available on crate feature unstable-msc4354 only.
pub fn with_sticky_duration(self, duration: Duration) -> Self
unstable-msc4354 only.Make this event sticky for duration, clamped to one hour.
Note that if the homeserver doesn’t support sticky events, it will
ignore the duration and send the event unsticky. Server support can
be checked with Client::supports_sticky_events.
Sourcepub fn with_transaction_id(self, txn_id: &TransactionId) -> Self
pub fn with_transaction_id(self, txn_id: &TransactionId) -> Self
Set a transaction ID for this event.
Since sending message-like events always requires a transaction ID, one is generated if this method is not called.
- On the sending side, this field is used for re-trying earlier failed transactions. Subsequent messages must never re-use an earlier transaction ID.
- On the receiving side, the field is used for recognizing our own
messages when they arrive down the sync: the server includes the ID in
the
MessageLikeUnsignedfieldtransaction_idof the correspondingSyncMessageLikeEvent, but only for the sending device. Other devices will not see it. This is then used to ignore events sent by our own device and/or to implement local echo.
Sourcepub fn with_request_config(self, request_config: RequestConfig) -> Self
pub fn with_request_config(self, request_config: RequestConfig) -> Self
Assign a given RequestConfig to configure how this request should
behave with respect to the network.